import { ref, onMounted } from 'vue'

export function useUni() {
    const platform = ref('')  // 存储当前的平台

    // 判断是否在微信浏览器中
    const checkWeixinBrowser = () => {
        return /MicroMessenger/i.test(navigator.userAgent)
    }

    // 获取当前平台并判断环境
    const getCurrentPlatform = async () => {
        try {
            uni.getEnv(env => {
                if (env.h5) {
                    // 如果是 H5 环境，检查是否在微信浏览器中
                    if (checkWeixinBrowser()) {
                        platform.value = 'h5-weixin'
                    } else {
                        platform.value = 'h5'  // 当前是 Web 平台
                    }
                } else if (env['mp-weixin']) {
                    platform.value = 'mp-weixin'  // 当前是 微信小程序平台
                } else if (env.app) {
                    platform.value = 'app'  // 当前是 App 平台
                } else if (env['mp-qq']) {
                    platform.value = 'mp-qq'  // 当前是 QQ 小程序平台
                } else if (env['mp-alipay']) {
                    platform.value = 'mp-alipay'  // 当前是 支付宝小程序平台
                } else {
                    platform.value = 'unknown'  // 未知平台
                }
            })
        } catch (error) {
            console.error('获取平台信息失败:', error)
            platform.value = 'unknown'
        }
    }

    // 在组件挂载时执行环境判断
    onMounted(() => {
        getCurrentPlatform()
    })

    return {
        platform,
        getCurrentPlatform,
    }
}
