import { ref, onMounted } from "vue";

export function useWebView() {
    const platform = ref("");
    const token = ref("");

    // 检测环境并通知父窗口加载完毕
    const handleBridgeReady = (platformName) => {
        if (platformName.h5) {
            window.parent.postMessage({ loaded: true }, "*");
        }
    };

    const handlePaymentMessage = () => {
        if (platformName.h5) {
            window.parent.postMessage({ loaded: true }, "*");
        }
    }

    // 获取 Token（从 URL 中解析）
    const getTokenFromUrl = () => {
        const urlParams = new URLSearchParams(window.location.search);
        const tokenFromUrl = urlParams.get("token");
        token.value = tokenFromUrl || ""; // 如果 URL 没有 token，返回空字符串
        if (token.value) {
            localStorage.setItem("token", token.value);
        }
        return tokenFromUrl;
    };

    onMounted(() => {
        // 检测平台环境
        uni.getEnv((env) => {
            platform.value = env;
            handleBridgeReady(platform.value);
        });

        // 获取 Token
        getTokenFromUrl();
    });

    return {
        platform,
        token,
        handlePaymentMessage
    };
}
