import { createRouter, createWebHistory } from 'vue-router'
import NProgress from 'nprogress';

const router = createRouter({
  history: createWebHistory(import.meta.env.BASE_URL),
  routes: [
    {
      path: '/',
      name: 'home',
      component: () => import('@/views/Home.vue'),
    },
    {
      path: '/service',
      name: 'service',
      component: () => import('@/views/Service.vue'),
    },
    {
      path: '/complaint',
      name: 'complaint',
      component: () => import('@/views/Complaint.vue'),
    },
    {
      path: '/report',
      name: 'report',
      component: () => import('@/views/Report.vue'),
    },
    {
      path: '/example',
      name: 'example',
      component: () => import('@/views/Example.vue'),
    },
    {
      path: '/authorization',
      name: 'authorization',
      component: () => import('@/views/Authorization.vue'),
    },
    {
      path: '/privacyPolicy',
      name: 'privacyPolicy',
      component: () => import('@/views/PrivacyPolicy.vue'),
    },
    {
      path: '/userAgreement',
      name: 'userAgreement',
      component: () => import('@/views/UserAgreement.vue'),
    },
    {
      path: '/listMarriage',
      name: 'listMarriage',
      component: () => import('@/views/list_marriage.vue'),
    },
    {
      path: '/listRisk',
      name: 'listRisk',
      component: () => import('@/views/list_risk.vue'),
    },
    {
      path: '/listLawsuit',
      name: 'listLawsuit',
      component: () => import('@/views/list_lawsuit.vue'),
    },
    {
      path: '/listVerify',
      name: 'listVerify',
      component: () => import('@/views/list_verify.vue'),
    },
    {
      path: '/inquire/:feature',
      name: 'inquire',
      component: () => import('@/views/Inquire.vue'),
    },
    {
      path: "/:pathMatch(.*)*",
      name: "NotFound",
      component: () => import('@/views/NotFound.vue')
    },
  ],
})
NProgress.configure({
  easing: 'ease',          // 动画方式
  speed: 500,              // 递增进度条的速度（毫秒）
  showSpinner: false,       // 是否显示加载的圆圈
  trickleSpeed: 200,       // 自动递增间隔
  minimum: 0.3,            // 初始化最小百分比
});

// 路由导航守卫
router.beforeEach((to, from, next) => {
  NProgress.start(); // 启动进度条
  next();
});

router.afterEach(() => {
  NProgress.done(); // 结束进度条
});
export default router
